@@ -6,7 +6,7 @@
 which astyle > /dev/null
 RET=$?
 if [ $RET -ne 0 ]; then
-	echo "Could not find astyle - aborting." 
+	echo "Could not find astyle - aborting."
 	exit
 fi
 
@@ -20,8 +20,8 @@ fi
 # Find all "pure" C files in the codebase
 #   - not .in.c used for .sql generation
 #   - not lex.yy.c or wktparse.tab.c as these are generated files
-CFILES=`find . -name '*.c' -not \( -name '*.in.c' -o -name '*_parse.c' -o -name '*_lex.c' \)`
+CFILES=`find . -name '*.c' -not \( -name '*_parse.c' -o -name '*_lex.c' \)`
 
-# Run the standard format on the files, and do not 
+# Run the standard format on the files, and do not
 # leave .orig files around for altered files.
 astyle --style=ansi --indent=tab --suffix=none $CFILES
