@@ -2,21 +2,19 @@
 set -e
 #### $Id:build_postgis210.sh 10208 2012-08-30 05:38:22Z robe $
 #all these get passed in by jenkins
-#export OS_BUILD=64 
+#export OS_BUILD=64
 #export PG_VER=9.2beta2
 #export PGHOST=localhost
 #export PGPORT=8442
-#export PGUSER=postgres
-#export GEOS_VER=3.4.0dev
-#export GDAL_VER=1.9.1
 #POSTGIS_SVN_REVISION=passed_in_by_buildbot
-#POSTGIS_MAJOR_VERSION=2
-#POSTGIS_MINOR_VERSION=1
-#POSTGIS_MICRO_VERSION=0SVN
-#export GCC_TYPE=gcc48  #for pre-4.8.0 compiles this is blank
-#export JSON_VER=0.9
-#export SFCGAL_VER=1.0.4
-#export PROJ_VER=4.8.0
+
+export GEOS_VER=3.7.0dev
+export GDAL_VER=2.2.2
+export PROJ_VER=4.9.3
+export SFCGAL_VER=1.3
+export PCRE_VER=8.33
+export PROTOBUF_VER=3.2.0
+export PROTOBUFC_VER=1.2.1
 
 export PROTOBUF_VER=3.2.0
 export LIBXML_VER=2.7.8
@@ -61,7 +59,7 @@ fi;
 
 #export POSTGIS_SRC=${PROJECTS}/postgis/trunk
 export GDAL_DATA="${PROJECTS}/gdal/rel-${GDAL_VER}w${OS_BUILD}${GCC_TYPE}/share/gdal"
-# export REL_PGVER=$(echo $PG_VER | tr '.' '') 
+# export REL_PGVER=$(echo $PG_VER | tr '.' '')
 # echo $REL_PGVER
 # export RELDIR=${MINGPROJECTS}/postgis/builds/postgis-21
 # export RELVERDIR=postgis-pg${REL_PGVER}-binaries-${POSTGIS_MICRO_VER}w64
@@ -102,7 +100,7 @@ if [ -n "$SFCGAL_VER" ]; then
 	#BOOST_VER_WU=1_49_0
 	export BOOST_VER_WU=1_53_0
 	export PATH="${PROJECTS}/CGAL/rel-cgal-${CGAL_VER}w${OS_BUILD}${GCC_TYPE}/bin:${PROJECTS}/boost/rel-${BOOST_VER_WU}w${OS_BUILD}${GCC_TYPE}/lib:${PATH}"
-	
+
 CPPFLAGS="-I${PGPATH}/include -I${MINGPROJECTS}/rel-libiconv-1.13.1w${OS_BUILD}${GCC_TYPE}/include" \
 LDFLAGS="-L${PGPATH}/lib -L${PROJECTS}/gdal/rel-${GDAL_VER}w${OS_BUILD}${GCC_TYPE}/lib -L${MINGPROJECTS}/rel-libiconv-1.13.1w${OS_BUILD}${GCC_TYPE}/lib" ./configure \
   --host=${MINGHOST} --with-xml2config=${PROJECTS}/libxml/rel-libxml2-${LIBXML_VER}w${OS_BUILD}${GCC_TYPE}/bin/xml2-config \
