@@ -1,5 +1,4 @@
 /**********************************************************************
- * $Id: generator.c 3967 2009-05-04 16:48:11Z kneufeld $
  *
  * PostGIS - Spatial Types for PostgreSQL
  * http://postgis.net
@@ -33,8 +32,10 @@
 #include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
+#include <sys/wait.h> /* for WEXITSTATUS */
 
 #include "liblwgeom.h"
+#include "liblwgeom_internal.h" /* for trim_trailing_zeros */
 #include "lwgeom_log.h"
 #include "styles.h"
 
@@ -48,6 +49,15 @@ char *imageSize = "200x200";
 
 int getStyleName(char **styleName, char* line);
 
+static void
+checked_system(const char* cmd)
+{
+  int ret = system(cmd);
+	if ( WEXITSTATUS(ret) != 0 ) {
+		fprintf(stderr, "Failure return code (%d) from command: %s", WEXITSTATUS(ret), cmd);
+	}
+}
+
 /**
  * Writes the coordinates of a POINTARRAY to a char* where ordinates are
  * separated by a comma and coordinates by a space so that the coordinate
@@ -230,7 +240,7 @@ addDropShadow(int layerNumber)
 	    "convert tmp%d.png -gravity center \"(\" +clone -background navy -shadow 100x3+4+4 \")\" +swap -background none -flatten tmp%d.png",
 	    layerNumber, layerNumber);
 	LWDEBUGF(4, "%s", str);
-	system(str);
+	checked_system(str);
 }
 
 /**
@@ -249,7 +259,7 @@ addHighlight(int layerNumber)
 	    "convert tmp%d.png \"(\" +clone -channel A -separate +channel -negate -background black -virtual-pixel background -blur 0x3 -shade 120x55 -contrast-stretch 0%% +sigmoidal-contrast 7x50%% -fill grey50 -colorize 10%% +clone +swap -compose overlay -composite \")\" -compose In -composite tmp%d.png",
 	    layerNumber, layerNumber);
 	LWDEBUGF(4, "%s", str);
-	system(str);
+	checked_system(str);
 }
 
 /**
@@ -265,7 +275,7 @@ optimizeImage(char* filename)
 	str = malloc( (18 + (2*strlen(filename)) + 1) * sizeof(char) );
 	sprintf(str, "convert %s -depth 8 %s", filename, filename);
 	LWDEBUGF(4, "%s", str);
-	system(str);
+	checked_system(str);
 	free(str);
 }
 
@@ -275,12 +285,11 @@ optimizeImage(char* filename)
 static void
 flattenLayers(char* filename)
 {
-	char *str;
-	str = malloc( (48 + strlen(filename) + 1) * sizeof(char) );
+	char *str = malloc( (48 + strlen(filename) + 1) * sizeof(char) );
 	sprintf(str, "convert tmp[0-9].png -background white -flatten %s", filename);
 
 	LWDEBUGF(4, "%s", str);
-	system(str);
+	checked_system(str);
 	// TODO: only remove the tmp files if they exist.
 	remove("tmp0.png");
 	remove("tmp1.png");
@@ -330,7 +339,6 @@ int main( int argc, const char* argv[] )
 	char line [2048];
 	char *filename;
 	int layerCount;
-	int styleNumber;
 	LAYERSTYLE *styles;
 	char *image_path = "../images/";
 
@@ -362,6 +370,7 @@ int main( int argc, const char* argv[] )
 		char output[32768];
 		char *ptr = output;
 		char *styleName;
+		LAYERSTYLE *style;
 		int useDefaultStyle;
 
 		ptr += sprintf( ptr, "convert -size %s xc:none ", imageSize );
@@ -378,15 +387,19 @@ int main( int argc, const char* argv[] )
 			lwgeom = lwgeom_from_wkt( line+strlen(styleName)+1, LW_PARSER_CHECK_NONE );
 		LWDEBUGF( 4, "geom = %s", lwgeom_to_ewkt((LWGEOM*)lwgeom) );
 
-		styleNumber = layerCount % length(styles);
-		ptr += drawGeometry( ptr, lwgeom, getStyle(styles, styleName) );
+		style = getStyle(styles, styleName);
+		if ( ! style ) {
+		  lwerror("Could not find style named %s", styleName);
+		  return -1;
+		}
+		ptr += drawGeometry( ptr, lwgeom, style );
 
 		ptr += sprintf( ptr, "-flip tmp%d.png", layerCount );
 
 		lwfree( lwgeom );
 
 		LWDEBUGF( 4, "%s", output );
-		system(output);
+		checked_system(output);
 
 		addHighlight( layerCount );
 		addDropShadow( layerCount );
