@@ -109,7 +109,7 @@ static void test_lw_arc_center(void)
 	CU_ASSERT_DOUBLE_EQUAL(d1, 0.0046097720751, 0.0001);
 	CU_ASSERT_DOUBLE_EQUAL(c1.x, 2047538.599, 0.001);
 	CU_ASSERT_DOUBLE_EQUAL(c1.y, 7268770.4395, 0.001);
-	
+
 	// printf("lw_arc_center: (%12.12g, %12.12g) %12.12g\n", c1.x, c1.y, d1);
 }
 
@@ -788,7 +788,7 @@ static void test_geohash(void)
 	lwline = (LWLINE*)lwgeom_from_wkt("LINESTRING(23.0 23.0,23.001 23.001)", LW_PARSER_CHECK_NONE);
 	geohash = lwgeom_geohash((LWGEOM*)lwline,0);
 	//printf("geohash %s\n",geohash);
-	CU_ASSERT_STRING_EQUAL(geohash, "ss06g7");
+	CU_ASSERT_STRING_EQUAL(geohash, "ss06g7h");
 	lwline_free(lwline);
 	lwfree(geohash);
 
@@ -910,7 +910,7 @@ static void test_geohash_point_as_int(void)
 	unsigned int gh;
 	POINT2D p;
 	unsigned long long rs;
-	
+
 	p.x = 50; p.y = 35;
 	gh = geohash_point_as_int(&p);
 	rs = 3440103613;
@@ -962,7 +962,7 @@ static void test_lwgeom_simplify(void)
 		CU_ASSERT_EQUAL(l, NULL);
 		lwgeom_free(g);
 		lwgeom_free(l);
-		
+
 		/* Not simplifiable */
 		g = lwgeom_from_wkt("LINESTRING(0 0, 50 1.00001, 100 0)", LW_PARSER_CHECK_NONE);
 		l = lwgeom_simplify(g, 1.0, LW_FALSE);
@@ -1011,7 +1011,7 @@ static void do_median_test(char* input, char* expected)
 
 	LWPOINT* result = lwgeom_median(g, FP_TOLERANCE / 10.0, 1000, LW_TRUE);
 	int passed = LW_TRUE;
-	
+
 	lwpoint_getPoint3dz_p(result, &actual_pt);
 	lwpoint_getPoint3dz_p(expected_result, &expected_pt);
 
@@ -1105,7 +1105,7 @@ static void test_point_density(void)
 static void test_lwpoly_construct_circle(void)
 {
 	LWPOLY* p;
-	GBOX* g;
+	const GBOX* g;
 	const int srid = 4326;
 	const int segments_per_quad = 17;
 	const int x = 10;
@@ -1115,7 +1115,7 @@ static void test_lwpoly_construct_circle(void)
 	/* With normal arguments you should get something circle-y */
 	p = lwpoly_construct_circle(srid, x, y, r, segments_per_quad, LW_TRUE);
 
-	ASSERT_INT_EQUAL(lwgeom_count_vertices(p), segments_per_quad * 4 + 1);
+	ASSERT_INT_EQUAL(lwgeom_count_vertices(lwpoly_as_lwgeom(p)), segments_per_quad * 4 + 1);
 	ASSERT_INT_EQUAL(lwgeom_get_srid(lwpoly_as_lwgeom(p)), srid)
 
 	g = lwgeom_get_bbox(lwpoly_as_lwgeom(p));
@@ -1124,7 +1124,7 @@ static void test_lwpoly_construct_circle(void)
 	CU_ASSERT_DOUBLE_EQUAL(g->ymin, y-r, 0.1);
 	CU_ASSERT_DOUBLE_EQUAL(g->ymax, y+r, 0.1);
 
-	CU_ASSERT_DOUBLE_EQUAL(lwgeom_area(p), M_PI*5*5, 0.1);
+	CU_ASSERT_DOUBLE_EQUAL(lwgeom_area(lwpoly_as_lwgeom(p)), M_PI*5*5, 0.1);
 
 	lwpoly_free(p);
 
