@@ -1,5 +1,4 @@
 /**********************************************************************
- * $Id: cu_out_gml.c 13242 2015-02-19 00:22:22Z pramsey $
  *
  * PostGIS - Spatial Types for PostgreSQL
  * http://postgis.net
@@ -148,26 +147,6 @@ static void do_gml2_unsupported(char * in, char * out)
 	lwgeom_free(g);
 }
 
-static void do_gml3_unsupported(char * in, char * out)
-{
-	LWGEOM *g;
-	char *h;
-	int opts = LW_GML_IS_DIMS;
-
-	g = lwgeom_from_wkt(in, LW_PARSER_CHECK_NONE);
-	h = lwgeom_to_gml3(g, NULL, 0, opts, "", NULL);
-
-	if (strcmp(cu_error_msg, out))
-		fprintf(stderr, "\nGML 3 - In:   %s\nOut:  %s\nTheo: %s\n",
-		        in, cu_error_msg, out);
-
-	CU_ASSERT_STRING_EQUAL(out, cu_error_msg);
-	cu_error_msg_reset();
-
-	lwfree(h);
-	lwgeom_free(g);
-}
-
 static void do_gml2_extent_test(char * in, char * out, char * srs,
                                    double precision, char * prefix)
 {
@@ -550,25 +529,26 @@ static void out_gml_test_geoms(void)
 	    "<gml:MultiGeometry><gml:geometryMember><gml:Point><gml:pos srsDimension=\"2\">0 1</gml:pos></gml:Point></gml:geometryMember><gml:geometryMember><gml:MultiGeometry><gml:geometryMember><gml:Curve><gml:segments><gml:LineStringSegment><gml:posList srsDimension=\"2\">2 3 4 5</gml:posList></gml:LineStringSegment></gml:segments></gml:Curve></gml:geometryMember></gml:MultiGeometry></gml:geometryMember></gml:MultiGeometry>",
 	    NULL, 0, 0);
 
-
-
 	/* GML2 - CircularString */
 	do_gml2_unsupported(
 	    "CIRCULARSTRING(-2 0,0 2,2 0,0 2,2 4)",
 	    "lwgeom_to_gml2: 'CircularString' geometry type not supported");
 	/* GML3 - CircularString */
-	do_gml3_unsupported(
-	    "CIRCULARSTRING(-2 0,0 2,2 0,0 2,2 4)",
-	    "lwgeom_to_gml3: 'CircularString' geometry type not supported");
+    do_gml3_test(
+                "CIRCULARSTRING(-2 0,0 2,2 0,0 2,2 4)",
+                "<gml:Curve><gml:segments><gml:ArcString><gml:posList srsDimension=\"2\">-2 0 0 2 2 0 0 2 2 4</gml:posList></gml:ArcString></gml:segments></gml:Curve>",
+                NULL, 0, 0 );
 
 	/* GML2 - CompoundCurve */
 	do_gml2_unsupported(
 	    "COMPOUNDCURVE(CIRCULARSTRING(0 0,1 1,1 0),(1 0,0 1))",
 	    "lwgeom_to_gml2: 'CompoundCurve' geometry type not supported");
 	/* GML3 - CompoundCurve */
-	do_gml3_unsupported(
-	    "COMPOUNDCURVE(CIRCULARSTRING(0 0,1 1,1 0),(1 0,0 1))",
-	    "lwgeom_to_gml3: 'CompoundCurve' geometry type not supported");
+
+    do_gml3_test(
+       "COMPOUNDCURVE(CIRCULARSTRING(0 0,1 1,1 0),(1 0,0 1))",
+                "<gml:Curve><gml:segments><gml:ArcString><gml:posList srsDimension=\"2\">0 0 1 1 1 0</gml:posList></gml:ArcString><gml:LineStringSegment><gml:posList srsDimension=\"2\">1 0 0 1</gml:posList></gml:LineStringSegment></gml:segments></gml:Curve>",
+                NULL, 0, 0 );
 
 	/* GML2 - CurvePolygon */
 	do_gml2_unsupported(
@@ -576,10 +556,14 @@ static void out_gml_test_geoms(void)
 	    "lwgeom_to_gml2: 'CurvePolygon' geometry type not supported");
 
 	/* GML3 - CurvePolygon */
-	do_gml3_unsupported(
-	    "CURVEPOLYGON(CIRCULARSTRING(-2 0,-1 -1,0 0,1 -1,2 0,0 2,-2 0),(-1 0,0 0.5,1 0,0 1,-1 0))",
-	    "lwgeom_to_gml3: 'CurvePolygon' geometry type not supported");
-
+    do_gml3_test(
+        "CURVEPOLYGON(CIRCULARSTRING(-2 0,-1 -1,0 0,1 -1,2 0,0 2,-2 0),(-1 0,0 0.5,1 0,0 1,-1 0))",
+                "<gml:Polygon><gml:exterior><gml:Ring><gml:curveMember><gml:Curve><gml:segments><gml:ArcString><gml:posList srsDimension=\"2\">-2 0 -1 -1 0 0 1 -1 2 0 0 2 -2 0</gml:posList></gml:ArcString></gml:segments></gml:Curve></gml:curveMember></gml:Ring></gml:exterior><gml:interior><gml:LinearRing><gml:posList srsDimension=\"2\">-1 0 0 0.5 1 0 0 1 -1 0</gml:posList></gml:LinearRing></gml:interior></gml:Polygon>",
+                NULL, 1, 0 );
+	do_gml3_test(
+		"CURVEPOLYGON(COMPOUNDCURVE((763650.600000001 189057.100000001,7636.35 189045.199999999, 763650.548999999 189057.844000001,763650.600000001 189057.100000001)))",
+				 "<gml:Polygon><gml:exterior><gml:Ring><gml:curveMember><gml:Curve><gml:segments><gml:LineStringSegment><gml:posList srsDimension=\"2\">763650.6 189057.1 7636.35 189045.2 763650.549 189057.844 763650.6 189057.1</gml:posList></gml:LineStringSegment></gml:segments></gml:Curve></gml:curveMember></gml:Ring></gml:exterior></gml:Polygon>",
+				NULL, 7, 0 );
 
 	/* GML2 - MultiCurve */
 	do_gml2_unsupported(
@@ -587,9 +571,10 @@ static void out_gml_test_geoms(void)
 	    "lwgeom_to_gml2: 'MultiCurve' geometry type not supported");
 
 	/* GML3 - MultiCurve */
-	do_gml3_unsupported(
-	    "MULTICURVE((5 5,3 5,3 3,0 3),CIRCULARSTRING(0 0,2 1,2 2))",
-	    "lwgeom_to_gml3: 'MultiCurve' geometry type not supported");
+    do_gml3_test(
+         "MULTICURVE((5 5,3 5,3 3,0 3),CIRCULARSTRING(0 0,2 1,2 2))",
+                "<gml:MultiCurve><gml:curveMember><gml:Curve><gml:segments><gml:LineStringSegment><gml:posList srsDimension=\"2\">5 5 3 5 3 3 0 3</gml:posList></gml:LineStringSegment></gml:segments></gml:Curve></gml:curveMember><gml:curveMember><gml:Curve><gml:segments><gml:ArcString><gml:posList srsDimension=\"2\">0 0 2 1 2 2</gml:posList></gml:ArcString></gml:segments></gml:Curve></gml:curveMember></gml:MultiCurve>",
+                NULL, 0, 0 );
 
 	/* GML2 - MultiSurface */
 	do_gml2_unsupported(
@@ -597,9 +582,10 @@ static void out_gml_test_geoms(void)
 	    "lwgeom_to_gml2: 'MultiSurface' geometry type not supported");
 
 	/* GML3 - MultiSurface */
-	do_gml3_unsupported(
-	    "MULTISURFACE(CURVEPOLYGON(CIRCULARSTRING(-2 0,-1 -1,0 0,1 -1,2 0,0 2,-2 0),(-1 0,0 0.5,1 0,0 1,-1 0)),((7 8,10 10,6 14,4 11,7 8)))",
-	    "lwgeom_to_gml3: 'MultiSurface' geometry type not supported");
+    do_gml3_test(
+                "MULTISURFACE(CURVEPOLYGON(CIRCULARSTRING(-2 0,-1 -1,0 0,1 -1,2 0,0 2,-2 0),(-1 0,0 0.5,1 0,0 1,-1 0)),((7 8,10 10,6 14,4 11,7 8)))",
+                "<gml:MultiSurface><gml:Polygon><gml:exterior><gml:Ring><gml:curveMember><gml:Curve><gml:segments><gml:ArcString><gml:posList srsDimension=\"2\">-2 0 -1 -1 0 0 1 -1 2 0 0 2 -2 0</gml:posList></gml:ArcString></gml:segments></gml:Curve></gml:curveMember></gml:Ring></gml:exterior><gml:interior><gml:LinearRing><gml:posList srsDimension=\"2\">-1 0 0 0.5 1 0 0 1 -1 0</gml:posList></gml:LinearRing></gml:interior></gml:Polygon><gml:Polygon><gml:exterior><gml:LinearRing><gml:posList srsDimension=\"2\">7 8 10 10 6 14 4 11 7 8</gml:posList></gml:LinearRing></gml:exterior></gml:Polygon></gml:MultiSurface>",
+                NULL, 1, 0 );
 
 	/* GML2 - PolyhedralSurface */
 	do_gml2_unsupported(
@@ -1083,7 +1069,7 @@ static void out_gml3_extent(void)
 void out_gml_suite_setup(void);
 void out_gml_suite_setup(void)
 {
-	CU_pSuite suite = CU_add_suite("GML Output", NULL, NULL);
+	CU_pSuite suite = CU_add_suite("gml_output", NULL, NULL);
 	PG_ADD_TEST(suite, out_gml_test_precision);
 	PG_ADD_TEST(suite, out_gml_test_srid);
 	PG_ADD_TEST(suite, out_gml_test_dims);
