@@ -44,6 +44,7 @@ extern void in_geojson_suite_setup(void);
 extern void iterator_suite_setup(void);
 extern void twkb_in_suite_setup(void);
 extern void libgeom_suite_setup(void);
+extern void lwstroke_suite_setup(void);
 extern void measures_suite_setup(void);
 extern void effectivearea_suite_setup(void);
 extern void minimum_bounding_circle_suite_setup(void);
@@ -93,6 +94,7 @@ PG_SuiteSetup setupfuncs[] =
     iterator_suite_setup,
 	twkb_in_suite_setup,
 	libgeom_suite_setup,
+	lwstroke_suite_setup,
 	measures_suite_setup,
 	effectivearea_suite_setup,
 	minimum_bounding_circle_suite_setup,
