@@ -19,6 +19,7 @@
  **********************************************************************
  *
  * Copyright 2009 Paul Ramsey <pramsey@cleverelephant.ca>
+ * Copyright 2017 Darafei Praliaskouski <me@komzpa.net>
  *
  **********************************************************************/
 
@@ -109,7 +110,7 @@ int32_t gserialized_get_srid(const GSERIALIZED *s)
 	if ( srid == 0 )
 		return SRID_UNKNOWN;
 	else
-		return clamp_srid(srid);
+		return srid;
 }
 
 void gserialized_set_srid(GSERIALIZED *s, int32_t srid)
@@ -128,6 +129,15 @@ void gserialized_set_srid(GSERIALIZED *s, int32_t srid)
 	s->srid[2] = (srid & 0x000000FF);
 }
 
+inline static int gserialized_cmp_srid(const GSERIALIZED *s1, const GSERIALIZED *s2)
+{
+	return (
+		s1->srid[0] == s2->srid[0] &&
+		s1->srid[1] == s2->srid[1] &&
+		s1->srid[2] == s2->srid[2]
+	) ? 0 : 1;
+}
+
 GSERIALIZED* gserialized_copy(const GSERIALIZED *g)
 {
 	GSERIALIZED *g_out = NULL;
@@ -240,11 +250,14 @@ static uint64_t uint32_interleave_2(uint32_t u1, uint32_t u2)
 }
 #endif
 
+union floatuint {
+	uint32_t u;
+	float f;
+};
 
 uint64_t gbox_get_sortable_hash(const GBOX *g)
 {
-	uint32_t ux, uy;
-	float fx, fy;
+	union floatuint x, y;
 
 	/*
 	* Since in theory the bitwise representation of an IEEE
@@ -261,27 +274,63 @@ uint64_t gbox_get_sortable_hash(const GBOX *g)
 		p.z = (g->zmax + g->zmin) / 2.0;
 		normalize(&p);
 		cart2geog(&p, &gpt);
-		fx = gpt.lon;
-		fy = gpt.lat;
-		memcpy(&ux, &fx, sizeof(uint32_t));
-		memcpy(&uy, &fy, sizeof(uint32_t));
+		x.f = gpt.lon;
+		y.f = gpt.lat;
 	}
 	else
 	{
-		fx = (g->xmax + g->xmin) / 2.0;
-		fy = (g->ymax + g->ymin) / 2.0;
-		memcpy(&ux, &fx, sizeof(uint32_t));
-		memcpy(&uy, &fy, sizeof(uint32_t));
+		/*
+		* Here we'd like to get two ordinates from 4 in the box.
+		* Since it's just a sortable bit representation we can omit division from (A+B)/2.
+		* All it should do is subtract 1 from exponent anyways.
+		*/
+		x.f = g->xmax + g->xmin;
+		y.f = g->ymax + g->ymin;
 	}
-	return uint32_interleave_2(ux, uy);
+	return uint32_interleave_2(x.u, y.u);
 }
 
 int gserialized_cmp(const GSERIALIZED *g1, const GSERIALIZED *g2)
 {
 	int g1_is_empty, g2_is_empty, cmp;
 	GBOX box1, box2;
+	uint64_t hash1, hash2;
 	size_t sz1 = SIZE_GET(g1->size);
 	size_t sz2 = SIZE_GET(g2->size);
+	union floatuint x, y;
+
+	/*
+	* For two non-same planar points, we can skip a lot of machinery.
+	*/
+	if (
+		sz1 > 16 && // 16 is size of EMPTY, if it's larger - it has coordinates
+		sz2 > 16 &&
+		*(uint32_t*)(g1->data) == POINTTYPE &&
+		*(uint32_t*)(g2->data) == POINTTYPE &&
+		!FLAGS_GET_BBOX(g1->flags) &&
+		!FLAGS_GET_GEODETIC(g1->flags) &&
+		!FLAGS_GET_BBOX(g2->flags) &&
+		!FLAGS_GET_GEODETIC(g2->flags)
+	)
+	{
+		double *dptr = (double*)(g1->data);
+		x.f = 2.0 * dptr[1];
+		y.f = 2.0 * dptr[2];
+		hash1 = uint32_interleave_2(x.u, y.u);
+
+		dptr = (double*)(g2->data);
+		x.f = 2.0 * dptr[1];
+		y.f = 2.0 * dptr[2];
+		hash2 = uint32_interleave_2(x.u, y.u);
+
+		if ( hash1 > hash2 )
+			return 1;
+		if ( hash1 < hash2 )
+			return -1;
+
+		// if hashes happen to be the same, go to full compare.
+	}
+
 	size_t hsz1 = gserialized_header_size(g1);
 	size_t hsz2 = gserialized_header_size(g2);
 
@@ -291,22 +340,20 @@ int gserialized_cmp(const GSERIALIZED *g1, const GSERIALIZED *g2)
 	size_t bsz2 = sz2 - hsz2;
 	size_t bsz = bsz1 < bsz2 ? bsz1 : bsz2;
 
-	uint64_t hash1, hash2;
-	int32_t srid1 = gserialized_get_srid(g1);
-	int32_t srid2 = gserialized_get_srid(g2);
+	int cmp_srid = gserialized_cmp_srid(g1, g2);
 
 	g1_is_empty = (gserialized_get_gbox_p(g1, &box1) == LW_FAILURE);
 	g2_is_empty = (gserialized_get_gbox_p(g2, &box2) == LW_FAILURE);
 
 	/* Empty == Empty */
 	if (g1_is_empty && g2_is_empty)
-    {
-        /* POINT EMPTY == POINT EMPTY */
-        /* POINT EMPTY < LINESTRING EMPTY */
-        uint32_t t1 = gserialized_get_type(g1);
-        uint32_t t2 = gserialized_get_type(g2);
+	{
+		/* POINT EMPTY == POINT EMPTY */
+		/* POINT EMPTY < LINESTRING EMPTY */
+		uint32_t t1 = gserialized_get_type(g1);
+		uint32_t t2 = gserialized_get_type(g2);
 		return t1 == t2 ? 0 : (t1 < t2 ? -1 : 1);
-    }
+	}
 
 	/* Empty < Non-empty */
 	if (g1_is_empty)
@@ -318,12 +365,12 @@ int gserialized_cmp(const GSERIALIZED *g1, const GSERIALIZED *g2)
 
 	/* Return equality for perfect equality only */
 	cmp = memcmp(b1, b2, bsz);
-	if ( bsz1 == bsz2 && srid1 == srid2 && cmp == 0 )
+	if ( bsz1 == bsz2 && cmp_srid == 0 && cmp == 0 )
 		return 0;
 
 	/* Using the centroids, calculate somewhat sortable */
-    /* hash key. The key doesn't provide good locality over */
-    /* the +/- boundary, but otherwise is pretty OK */
+	/* hash key. The key doesn't provide good locality over */
+	/* the +/- boundary, but otherwise is pretty OK */
 	hash1 = gbox_get_sortable_hash(&box1);
 	hash2 = gbox_get_sortable_hash(&box2);
 
