@@ -219,6 +219,7 @@ LWCOLLECTION* lwcollection_add_lwgeom(LWCOLLECTION *col, const LWGEOM *geom)
 	{
 		if ( col->geoms[i] == geom )
 		{
+            lwerror("%s [%d] found duplicate geometry in collection %p == %p", __FILE__, __LINE__, col->geoms[i], geom);
 			LWDEBUGF(4, "Found duplicate geometry in collection %p == %p", col->geoms[i], geom);
 			return col;
 		}
@@ -340,7 +341,7 @@ void lwcollection_free(LWCOLLECTION *col)
 {
 	int i;
 	if ( ! col ) return;
-	
+
 	if ( col->bbox )
 	{
 		lwfree(col->bbox);
@@ -362,6 +363,8 @@ void lwcollection_free(LWCOLLECTION *col)
 /**
 * Takes a potentially heterogeneous collection and returns a homogeneous
 * collection consisting only of the specified type.
+* WARNING: the output will contain references to geometries in the input,
+* so the result must be carefully released, not freed.
 */
 LWCOLLECTION* lwcollection_extract(LWCOLLECTION *col, int type)
 {
@@ -429,6 +432,10 @@ LWCOLLECTION* lwcollection_extract(LWCOLLECTION *col, int type)
 				geomlist[geomlistlen] = tmpcol->geoms[j];
 				geomlistlen++;
 			}
+			if (tmpcol->geoms)
+				lwfree(tmpcol->geoms);
+			if (tmpcol->bbox)
+				lwfree(tmpcol->bbox);
 			lwfree(tmpcol);
 		}
 	}
@@ -471,7 +478,7 @@ LWCOLLECTION*
 lwcollection_force_dims(const LWCOLLECTION *col, int hasz, int hasm)
 {
 	LWCOLLECTION *colout;
-	
+
 	/* Return 2D empty */
 	if( lwcollection_is_empty(col) )
 	{
@@ -574,7 +581,7 @@ lwcollection_startpoint(const LWCOLLECTION* col, POINT4D* pt)
 {
 	if ( col->ngeoms < 1 )
 		return LW_FAILURE;
-		
+
 	return lwgeom_startpoint(col->geoms[0], pt);
 }
 
@@ -583,7 +590,7 @@ LWCOLLECTION* lwcollection_grid(const LWCOLLECTION *coll, const gridspec *grid)
 {
 	uint32_t i;
 	LWCOLLECTION *newcoll;
-	
+
 	newcoll = lwcollection_construct_empty(coll->type, coll->srid, lwgeom_has_z((LWGEOM*)coll), lwgeom_has_m((LWGEOM*)coll));
 
 	for (i=0; i<coll->ngeoms; i++)
