@@ -209,14 +209,14 @@ GEOS2LWGEOM(const GEOSGeometry *geom, char want3d)
 
 
 
-GEOSCoordSeq ptarray_to_GEOSCoordSeq(const POINTARRAY *);
-
+GEOSCoordSeq ptarray_to_GEOSCoordSeq(const POINTARRAY *, int fix_ring);
 
 GEOSCoordSeq
-ptarray_to_GEOSCoordSeq(const POINTARRAY *pa)
+ptarray_to_GEOSCoordSeq(const POINTARRAY *pa, int fix_ring)
 {
 	uint32_t dims = 2;
 	uint32_t i;
+	int append_points = 0;
 	const POINT3DZ *p3d;
 	const POINT2D *p2d;
 	GEOSCoordSeq sq;
@@ -224,7 +224,27 @@ ptarray_to_GEOSCoordSeq(const POINTARRAY *pa)
 	if ( FLAGS_GET_Z(pa->flags) )
 		dims = 3;
 
-	if ( ! (sq = GEOSCoordSeq_create(pa->npoints, dims)) )
+	if ( fix_ring )
+	{
+		if (pa->npoints < 1)
+		{
+			lwerror("ptarray_to_GEOSCoordSeq called with fix_ring and 0 vertices in ring, cannot fix");
+			return NULL;
+		}
+		else
+		{
+			if ( pa->npoints < 4 )
+			{
+				append_points = 4 - pa->npoints;
+			}
+			if ( ! ptarray_is_closed_2d(pa) && append_points == 0 )
+			{
+				append_points = 1;
+			}
+		}
+	}
+
+	if ( ! (sq = GEOSCoordSeq_create(pa->npoints + append_points, dims)) )
 	{
 		lwerror("Error creating GEOS Coordinate Sequence");
 		return NULL;
@@ -248,41 +268,48 @@ ptarray_to_GEOSCoordSeq(const POINTARRAY *pa)
 		GEOSCoordSeq_setY(sq, i, p2d->y);
 
 		if ( dims == 3 )
+		{
 			GEOSCoordSeq_setZ(sq, i, p3d->z);
+		}
 	}
+
+	if ( append_points )
+	{
+		if ( dims == 3 )
+		{
+			p3d = getPoint3dz_cp(pa, 0);
+			p2d = (const POINT2D *)p3d;
+		}
+		else
+		{
+			p2d = getPoint2d_cp(pa, 0);
+		}
+		for ( i = pa->npoints; i < pa->npoints + append_points; i++ )
+		{
+			GEOSCoordSeq_setX(sq, i, p2d->x);
+			GEOSCoordSeq_setY(sq, i, p2d->y);
+
+			if ( dims == 3 )
+			{
+				GEOSCoordSeq_setZ(sq, i, p3d->z);
+			}
+		}
+	}
+
 	return sq;
 }
 
-static GEOSGeometry *
+static inline GEOSGeometry *
 ptarray_to_GEOSLinearRing(const POINTARRAY *pa, int autofix)
 {
 	GEOSCoordSeq sq;
 	GEOSGeom g;
-	POINTARRAY *npa = 0;
-
-	if ( autofix )
-	{
-		/* check ring for being closed and fix if not */
-		if ( ! ptarray_is_closed_2d(pa) )
-		{
-			npa = ptarray_addPoint(pa, getPoint_internal(pa, 0), FLAGS_NDIMS(pa->flags), pa->npoints);
-			pa = npa;
-		}
-		/* TODO: check ring for having at least 4 vertices */
-#if 0
-		while ( pa->npoints < 4 )
-		{
-			npa = ptarray_addPoint(npa, getPoint_internal(pa, 0), FLAGS_NDIMS(pa->flags), pa->npoints);
-		}
-#endif
-	}
-
-	sq = ptarray_to_GEOSCoordSeq(pa);
-	if ( npa ) ptarray_free(npa);
+	sq = ptarray_to_GEOSCoordSeq(pa, autofix);
 	g = GEOSGeom_createLinearRing(sq);
 	return g;
 }
 
+
 GEOSGeometry *
 GBOX2GEOS(const GBOX *box)
 {
@@ -367,7 +394,7 @@ LWGEOM2GEOS(const LWGEOM *lwgeom, int autofix)
 		}
 		else
 		{
-			sq = ptarray_to_GEOSCoordSeq(lwp->point);
+			sq = ptarray_to_GEOSCoordSeq(lwp->point, 0);
 			g = GEOSGeom_createPoint(sq);
 		}
 		if ( ! g )
@@ -382,11 +409,11 @@ LWGEOM2GEOS(const LWGEOM *lwgeom, int autofix)
 		if ( lwl->points->npoints == 1 ) {
 			/* Duplicate point, to make geos-friendly */
 			lwl->points = ptarray_addPoint(lwl->points,
-		                           getPoint_internal(lwl->points, 0),
-		                           FLAGS_NDIMS(lwl->points->flags),
-		                           lwl->points->npoints);
+			                       getPoint_internal(lwl->points, 0),
+			                       FLAGS_NDIMS(lwl->points->flags),
+			                       lwl->points->npoints);
 		}
-		sq = ptarray_to_GEOSCoordSeq(lwl->points);
+		sq = ptarray_to_GEOSCoordSeq(lwl->points, 0);
 		g = GEOSGeom_createLineString(sq);
 		if ( ! g )
 		{
@@ -562,8 +589,7 @@ lwgeom_normalize(const LWGEOM *geom1)
 
 	if (result == NULL)
 	{
-	  lwerror("Error performing intersection: GEOS2LWGEOM: %s",
-	                lwgeom_geos_errmsg);
+		lwerror("Error performing intersection: GEOS2LWGEOM: %s", lwgeom_geos_errmsg);
 		return NULL ; /* never get here */
 	}
 
