@@ -94,6 +94,28 @@ lwpoly_construct_rectangle(char hasz, char hasm, POINT4D *p1, POINT4D *p2,
 	return lwpoly;
 }
 
+LWPOLY *
+lwpoly_construct_envelope(int srid, double x1, double y1, double x2, double y2)
+{
+	POINT4D p1, p2, p3, p4;
+	LWPOLY *poly;
+
+	p1.x = x1;
+	p1.y = y1;
+	p2.x = x1;
+	p2.y = y2;
+	p3.x = x2;
+	p3.y = y2;
+	p4.x = x2;
+	p4.y = y1;
+
+	poly = lwpoly_construct_rectangle(0, 0, &p1, &p2, &p3, &p4);
+	lwgeom_set_srid(lwpoly_as_lwgeom(poly), srid);
+	lwgeom_add_bbox(lwpoly_as_lwgeom(poly));
+
+	return poly;
+}
+
 LWPOLY*
 lwpoly_construct_circle(int srid, double x, double y, double radius, uint32_t segments_per_quarter, char exterior)
 {
@@ -226,7 +248,7 @@ lwpoly_add_ring(LWPOLY *poly, POINTARRAY *pa)
 {
 	if( ! poly || ! pa )
 		return LW_FAILURE;
-		
+
 	/* We have used up our storage, add some more. */
 	if( poly->nrings >= poly->maxrings )
 	{
@@ -234,11 +256,11 @@ lwpoly_add_ring(LWPOLY *poly, POINTARRAY *pa)
 		poly->rings = lwrealloc(poly->rings, new_maxrings * sizeof(POINTARRAY*));
 		poly->maxrings = new_maxrings;
 	}
-	
+
 	/* Add the new ring entry. */
 	poly->rings[poly->nrings] = pa;
 	poly->nrings++;
-	
+
 	return LW_SUCCESS;
 }
 
@@ -262,6 +284,24 @@ lwpoly_force_clockwise(LWPOLY *poly)
 
 }
 
+int
+lwpoly_is_clockwise(LWPOLY *poly)
+{
+	int i;
+
+	if ( lwpoly_is_empty(poly) )
+		return LW_TRUE;
+
+	if ( ptarray_isccw(poly->rings[0]) )
+		return LW_FALSE;
+
+	for ( i = 1; i < poly->nrings; i++)
+		if ( !ptarray_isccw(poly->rings[i]) )
+			return LW_FALSE;
+
+	return LW_TRUE;
+}
+
 void
 lwpoly_release(LWPOLY *lwpoly)
 {
@@ -379,7 +419,7 @@ LWPOLY*
 lwpoly_force_dims(const LWPOLY *poly, int hasz, int hasm)
 {
 	LWPOLY *polyout;
-	
+
 	/* Return 2D empty */
 	if( lwpoly_is_empty(poly) )
 	{
@@ -441,7 +481,7 @@ LWPOLY* lwpoly_simplify(const LWPOLY *ipoly, double dist, int preserve_collapsed
 		/* and this is a shell, we ensure it is kept */
 		if ( preserve_collapsed && i == 0 )
 			minvertices = 4;
-			
+
 		opts = ptarray_simplify(ipoly->rings[i], dist, minvertices);
 
 		LWDEBUGF(3, "ring%d simplified from %d to %d points", i, ipoly->rings[i]->npoints, opts->npoints);
@@ -483,7 +523,7 @@ lwpoly_area(const LWPOLY *poly)
 {
 	double poly_area = 0.0;
 	int i;
-	
+
 	if ( ! poly )
 		lwerror("lwpoly_area called with null polygon pointer!");
 
@@ -495,7 +535,7 @@ lwpoly_area(const LWPOLY *poly)
 		/* Empty or messed-up ring. */
 		if ( ring->npoints < 3 )
 			continue;
-		
+
 		ringarea = fabs(ptarray_signed_area(ring));
 		if ( i == 0 ) /* Outer ring, positive area! */
 			poly_area += ringarea;
@@ -547,10 +587,10 @@ int
 lwpoly_is_closed(const LWPOLY *poly)
 {
 	int i = 0;
-	
+
 	if ( poly->nrings == 0 )
 		return LW_TRUE;
-		
+
 	for ( i = 0; i < poly->nrings; i++ )
 	{
 		if (FLAGS_GET_Z(poly->flags))
@@ -559,12 +599,12 @@ lwpoly_is_closed(const LWPOLY *poly)
 				return LW_FALSE;
 		}
 		else
-		{	
+		{
 			if ( ! ptarray_is_closed_2d(poly->rings[i]) )
 				return LW_FALSE;
 		}
 	}
-	
+
 	return LW_TRUE;
 }
 
@@ -580,13 +620,13 @@ int
 lwpoly_contains_point(const LWPOLY *poly, const POINT2D *pt)
 {
 	int i;
-	
+
 	if ( lwpoly_is_empty(poly) )
 		return LW_FALSE;
-	
+
 	if ( ptarray_contains_point(poly->rings[0], pt) == LW_OUTSIDE )
 		return LW_FALSE;
-	
+
 	for ( i = 1; i < poly->nrings; i++ )
 	{
 		if ( ptarray_contains_point(poly->rings[i], pt) == LW_INSIDE )
@@ -633,7 +673,7 @@ LWPOLY* lwpoly_grid(const LWPOLY *poly, const gridspec *grid)
 			if ( ri ) continue;
 			else break; /* this is the external ring, no need to work on holes */
 		}
-		
+
 		if ( ! lwpoly_add_ring(opoly, newring) )
 		{
 			lwerror("lwpoly_grid, memory error");
