@@ -77,6 +77,34 @@ static char *lwgeomTypeName[] =
 	"Tin"
 };
 
+/*
+ * Default allocators
+ *
+ * We include some default allocators that use malloc/free/realloc
+ * along with stdout/stderr since this is the most common use case
+ *
+ */
+
+static void *
+default_allocator(size_t size)
+{
+	void *mem = malloc(size);
+	return mem;
+}
+
+static void
+default_freeor(void *mem)
+{
+	free(mem);
+}
+
+static void *
+default_reallocator(void *mem, size_t size)
+{
+	void *ret = realloc(mem, size);
+	return ret;
+}
+
 /*
  * Default lwnotice/lwerror handlers
  *
@@ -85,6 +113,66 @@ static char *lwgeomTypeName[] =
  * structure.
  */
 
+static void
+default_noticereporter(const char *fmt, va_list ap)
+{
+	char msg[LW_MSG_MAXLEN+1];
+	vsnprintf (msg, LW_MSG_MAXLEN, fmt, ap);
+	msg[LW_MSG_MAXLEN]='\0';
+	fprintf(stderr, "%s\n", msg);
+}
+
+static void
+default_debuglogger(int level, const char *fmt, va_list ap)
+{
+	char msg[LW_MSG_MAXLEN+1];
+	if ( POSTGIS_DEBUG_LEVEL >= level )
+	{
+		/* Space pad the debug output */
+		int i;
+		for ( i = 0; i < level; i++ )
+			msg[i] = ' ';
+		vsnprintf(msg+i, LW_MSG_MAXLEN-i, fmt, ap);
+		msg[LW_MSG_MAXLEN]='\0';
+		fprintf(stderr, "%s\n", msg);
+	}
+}
+
+static void
+default_errorreporter(const char *fmt, va_list ap)
+{
+	char msg[LW_MSG_MAXLEN+1];
+	vsnprintf (msg, LW_MSG_MAXLEN, fmt, ap);
+	msg[LW_MSG_MAXLEN]='\0';
+	fprintf(stderr, "%s\n", msg);
+	exit(1);
+}
+
+/**
+ * This function is called by programs which want to set up custom handling
+ * for memory management and error reporting
+ *
+ * Only non-NULL values change their respective handler
+ */
+void
+lwgeom_set_handlers(lwallocator allocator, lwreallocator reallocator,
+	        lwfreeor freeor, lwreporter errorreporter,
+	        lwreporter noticereporter) {
+
+	if ( allocator ) lwalloc_var = allocator;
+	if ( reallocator ) lwrealloc_var = reallocator;
+	if ( freeor ) lwfree_var = freeor;
+
+	if ( errorreporter ) lwerror_var = errorreporter;
+	if ( noticereporter ) lwnotice_var = noticereporter;
+}
+
+void
+lwgeom_set_debuglogger(lwdebuglogger debuglogger) {
+
+	if ( debuglogger ) lwdebug_var = debuglogger;
+}
+
 void
 lwnotice(const char *fmt, ...)
 {
@@ -124,93 +212,7 @@ lwdebug(int level, const char *fmt, ...)
 	va_end(ap);
 }
 
-/*
- * Default allocators
- *
- * We include some default allocators that use malloc/free/realloc
- * along with stdout/stderr since this is the most common use case
- *
- */
 
-static void *
-default_allocator(size_t size)
-{
-	void *mem = malloc(size);
-	return mem;
-}
-
-static void
-default_freeor(void *mem)
-{
-	free(mem);
-}
-
-static void *
-default_reallocator(void *mem, size_t size)
-{
-	void *ret = realloc(mem, size);
-	return ret;
-}
-
-static void
-default_noticereporter(const char *fmt, va_list ap)
-{
-	char msg[LW_MSG_MAXLEN+1];
-	vsnprintf (msg, LW_MSG_MAXLEN, fmt, ap);
-	msg[LW_MSG_MAXLEN]='\0';
-	printf("%s\n", msg);
-}
-
-static void
-default_debuglogger(int level, const char *fmt, va_list ap)
-{
-	char msg[LW_MSG_MAXLEN+1];
-	if ( POSTGIS_DEBUG_LEVEL >= level )
-	{
-		/* Space pad the debug output */
-		int i;
-		for ( i = 0; i < level; i++ )
-			msg[i] = ' ';
-		vsnprintf(msg+i, LW_MSG_MAXLEN-i, fmt, ap);
-		msg[LW_MSG_MAXLEN]='\0';
-		printf("%s\n", msg);
-	}
-}
-
-static void
-default_errorreporter(const char *fmt, va_list ap)
-{
-	char msg[LW_MSG_MAXLEN+1];
-	vsnprintf (msg, LW_MSG_MAXLEN, fmt, ap);
-	msg[LW_MSG_MAXLEN]='\0';
-	fprintf(stderr, "%s\n", msg);
-	exit(1);
-}
-
-/**
- * This function is called by programs which want to set up custom handling
- * for memory management and error reporting
- *
- * Only non-NULL values change their respective handler
- */
-void
-lwgeom_set_handlers(lwallocator allocator, lwreallocator reallocator,
-	        lwfreeor freeor, lwreporter errorreporter,
-	        lwreporter noticereporter) {
-
-	if ( allocator ) lwalloc_var = allocator;
-	if ( reallocator ) lwrealloc_var = reallocator;
-	if ( freeor ) lwfree_var = freeor;
-
-	if ( errorreporter ) lwerror_var = errorreporter;
-	if ( noticereporter ) lwnotice_var = noticereporter;
-}
-
-void
-lwgeom_set_debuglogger(lwdebuglogger debuglogger) {
-
-	if ( debuglogger ) lwdebug_var = debuglogger;
-}
 
 const char*
 lwtype_name(uint8_t type)
@@ -391,7 +393,7 @@ clamp_srid(int srid)
       ( srid % ( SRID_MAXIMUM - SRID_USER_MAXIMUM - 1 ) );
 		lwnotice("SRID value %d > SRID_MAXIMUM converted to %d", srid, newsrid);
 	}
-	
+
 	return newsrid;
 }
 
