@@ -831,8 +831,11 @@ projFileCreate(SHPDUMPERSTATE *state)
 				fp = fopen( pszFullname, "wb" );
 				if ( fp == NULL )
 				{
+					free(pszFullname);
+					free(query);
 					return 0;
 				}
+				else
 				{
 				    result = fputs (srtext,fp);
                     LWDEBUGF(3, "\n result %d proj SRText is %s .\n", result, srtext);
@@ -1156,6 +1159,7 @@ ShpDumperCreate(SHPDUMPERCONFIG *config)
 	/* Set any state defaults */
 	state->conn = NULL;
 	state->outtype = 's';
+	state->outshptype = 0;
 	state->geom_oid = 0;
 	state->geog_oid = 0;
 	state->schema = NULL;
@@ -1167,6 +1171,7 @@ ShpDumperCreate(SHPDUMPERCONFIG *config)
 	state->dbffieldtypes = NULL;
 	state->pgfieldnames = NULL;
 	state->big_endian = is_bigendian();
+	state->message[0] = '\0';
 	colmap_init(&state->column_map);
 
 	return state;
@@ -1557,9 +1562,13 @@ ShpDumperOpenTable(SHPDUMPERSTATE *state)
 		/* Issue warning if column has been renamed */
 		if (strcasecmp(dbffieldname, pgfieldname))
 		{
+			if ( snprintf(buf, 256, _("Warning, field %s renamed to %s\n"),
+							 pgfieldname, dbffieldname) >= 256 )
+			{
+				buf[255] = '\0';
+			}
 			/* Note: we concatenate all warnings from the main loop as this is useful information */
-			snprintf(buf, 256, _("Warning, field %s renamed to %s\n"), pgfieldname, dbffieldname);
-			strncat(state->message, buf, SHPDUMPERMSGLEN - strlen(state->message));
+			strncat(state->message, buf, SHPDUMPERMSGLEN - strlen(state->message) - 1);
 
 			ret = SHPDUMPERWARN;
 		}
@@ -1732,7 +1741,10 @@ ShpDumperOpenTable(SHPDUMPERSTATE *state)
 			*/
 			dbffieldsize = getMaxFieldSize(state->conn, state->schema, state->table, pgfieldname);
 			if (dbffieldsize == -1)
+			{
+				free(dbffieldname);
 				return 0;
+			}
 
 			if (!dbffieldsize)
 				dbffieldsize = 32;
@@ -2081,6 +2093,7 @@ int ShpLoaderGenerateShapeRow(SHPDUMPERSTATE *state)
 			{
 				snprintf(state->message, SHPDUMPERMSGLEN, _("Error parsing HEXEWKB for record %d"), state->currow);
 				PQclear(state->fetchres);
+				free(hexewkb);
 				return SHPDUMPERERR;
 			}
 
