@@ -33,11 +33,8 @@
 #include "lwgeom_rtree.h"
 #include "lwgeom_functions_analytic.h"
 
-#if POSTGIS_PGSQL_VERSION >= 93
+
 #include "access/htup_details.h"
-#else
-#include "access/htup.h"
-#endif
 
 /***********************************************************************
  * Simple Douglas-Peucker line simplification.
@@ -55,6 +52,8 @@ Datum ST_LineCrossingDirection(PG_FUNCTION_ARGS);
 Datum ST_MinimumBoundingRadius(PG_FUNCTION_ARGS);
 Datum ST_MinimumBoundingCircle(PG_FUNCTION_ARGS);
 Datum ST_GeometricMedian(PG_FUNCTION_ARGS);
+Datum ST_IsPolygonCCW(PG_FUNCTION_ARGS);
+Datum ST_IsPolygonCW(PG_FUNCTION_ARGS);
 
 
 static double determineSide(const POINT2D *seg1, const POINT2D *seg2, const POINT2D *point);
@@ -80,7 +79,7 @@ Datum LWGEOM_simplify2d(PG_FUNCTION_ARGS)
 	/* Can't simplify points! */
 	if ( type == POINTTYPE || type == MULTIPOINTTYPE )
 		PG_RETURN_POINTER(geom);
-		
+
 	in = lwgeom_from_gserialized(geom);
 
 	out = lwgeom_simplify(in, dist, preserve_collapsed);
@@ -129,7 +128,7 @@ Datum LWGEOM_SetEffectiveArea(PG_FUNCTION_ARGS)
 	PG_RETURN_POINTER(result);
 }
 
-	
+
 /***********************************************************************
  * --strk@kbt.io;
  ***********************************************************************/
@@ -197,7 +196,7 @@ Datum LWGEOM_line_interpolate_point(PG_FUNCTION_ARGS)
 
 		opa = ptarray_construct(lwgeom_has_z(geom), lwgeom_has_m(geom), 1);
 		ptarray_set_point4d(opa, 0, &pt);
-		
+
 		point = lwpoint_construct(line->srid, NULL, opa);
 		PG_RETURN_POINTER(geometry_serialize(lwpoint_as_lwgeom(point)));
 	}
@@ -335,7 +334,7 @@ Datum LWGEOM_snaptogrid(PG_FUNCTION_ARGS)
 	{
 		PG_RETURN_POINTER(in_geom);
 	}
-	
+
 	/* Return input geometry if input grid is meaningless */
 	if ( grid.xsize==0 && grid.ysize==0 && grid.zsize==0 && grid.msize==0 )
 	{
@@ -418,7 +417,7 @@ Datum LWGEOM_snaptogrid_pointoff(PG_FUNCTION_ARGS)
 #if POSTGIS_DEBUG_LEVEL >= 4
 	grid_print(&grid);
 #endif
-	
+
 	/* Return input geometry if input grid is meaningless */
 	if ( grid.xsize==0 && grid.ysize==0 && grid.zsize==0 && grid.msize==0 )
 	{
@@ -1278,7 +1277,61 @@ Datum ST_GeometricMedian(PG_FUNCTION_ARGS)
 	}
 
 	result = geometry_serialize(lwpoint_as_lwgeom(lwresult));
-	
+
 	PG_RETURN_POINTER(result);
 }
 
+/**********************************************************************
+ *
+ * ST_IsPolygonCW
+ *
+ **********************************************************************/
+
+PG_FUNCTION_INFO_V1(ST_IsPolygonCW);
+Datum ST_IsPolygonCW(PG_FUNCTION_ARGS)
+{
+	GSERIALIZED* geom;
+	LWGEOM* input;
+	bool is_clockwise;
+
+	if (PG_ARGISNULL(0))
+		PG_RETURN_NULL();
+
+	geom = PG_GETARG_GSERIALIZED_P(0);
+	input = lwgeom_from_gserialized(geom);
+
+	is_clockwise = lwgeom_is_clockwise(input);
+
+	lwgeom_free(input);
+	PG_FREE_IF_COPY(geom, 0);
+
+	PG_RETURN_BOOL(is_clockwise);
+}
+
+/**********************************************************************
+ *
+ * ST_IsPolygonCCW
+ *
+ **********************************************************************/
+
+PG_FUNCTION_INFO_V1(ST_IsPolygonCCW);
+Datum ST_IsPolygonCCW(PG_FUNCTION_ARGS)
+{
+	GSERIALIZED* geom;
+	LWGEOM* input;
+	bool is_ccw;
+
+	if (PG_ARGISNULL(0))
+		PG_RETURN_NULL();
+
+	geom = PG_GETARG_GSERIALIZED_P_COPY(0);
+	input = lwgeom_from_gserialized(geom);
+
+    lwgeom_reverse(input);
+	is_ccw = lwgeom_is_clockwise(input);
+
+	lwgeom_free(input);
+	PG_FREE_IF_COPY(geom, 0);
+
+	PG_RETURN_BOOL(is_ccw);
+}
