@@ -686,7 +686,7 @@ rt_errorstate rt_raster_get_inverse_geotransform_matrix(
 		rt_raster_get_geotransform_matrix(raster, _gt);
 	else
 		memcpy(_gt, gt, sizeof(double) * 6);
-	
+
 	if (!GDALInvGeoTransform(_gt, igt)) {
 		rterror("rt_raster_get_inverse_geotransform_matrix: Could not compute inverse geotransform matrix");
 		return ES_ERROR;
@@ -1288,7 +1288,7 @@ rt_raster_compute_skewed_raster(
 				raster->width--;
 			else
 				raster->height--;
-			
+
 			/* construct sgeom from raster */
 			if ((rt_raster_get_convex_hull(raster, &geom) != ES_NONE) || geom == NULL) {
 				rterror("rt_raster_compute_skewed_raster: Could not build skewed extent's geometry for minimizing dimensions");
@@ -1963,7 +1963,7 @@ rt_raster_to_gdal_mem(
 			RASTER_DEBUGF(4, "rt_raster_to_gdal_mem: szDatapointer is %p",
 				pszDataPointer);
 
-			if (strnicmp(pszDataPointer, "0x", 2) == 0)
+			if (strncasecmp(pszDataPointer, "0x", 2) == 0)
 				sprintf(szGDALOption, "DATAPOINTER=%s", pszDataPointer);
 			else
 				sprintf(szGDALOption, "DATAPOINTER=0x%s", pszDataPointer);
